Struct xous_ipc::String

source ·
pub struct String<const N: usize> { /* private fields */ }

Implementations

source

impl<const N: usize> String<N>

source

pub fn new() -> String<N>

source

pub fn volatile_clear(&mut self)

source

pub fn from_str<T>(src: T) -> String<N>
where T: AsRef<str>,

source

pub fn as_bytes(&self) -> [u8; N]

source

pub fn as_str(&self) -> Result<&str, Utf8Error>

source

pub fn len(&self) -> usize

source

pub fn is_empty(&self) -> bool

source

pub fn from_message(message: &MemoryMessage) -> Result<String<N>, Utf8Error>

Convert a MemoryMessage into a String

source

pub fn lend(&self, connection: CID) -> Result<Result, Error>

Perform an immutable lend of this String to the specified server. This function will block until the server returns. Note that this convenience should only be used if the server only ever expects to deal with one type of String, ever. Otherwise, this should be implemented in the API and wrapped in an Enum to help decorate the functional target of the string. An example of a server that uses this convencience function is the logger.

source

pub fn send(self, connection: CID) -> Result<Result, Error>

Move this string from the client into the server.

source

pub fn clear(&mut self)

Clear the contents of this String and set the length to 0

source

pub fn to_str(&self) -> &str

source

pub fn pop(&mut self) -> Option<char>

awful, O(N) implementation because we have to iterate through the entire string and decode variable-length utf8 characters, until we can’t.

source

pub fn push(&mut self, ch: char) -> Result<usize, Error>

source

pub fn append(&mut self, s: &str) -> Result<usize, Error>

source

pub fn push_byte(&mut self, b: u8) -> Result<(), Error>